extension StringExtension on String {
  /// 首字母转换为大写
  ///
  /// ```dart
  /// fooBar => FooBar
  /// ```
  String toCapitalize() {
    if (this.length < 2) return this.toUpperCase();
    return this[0].toUpperCase() + this.substring(1);
  }

  /// 转换为LowerCamel型式
  ///
  ///
  /// ```dart
  /// FooBar => fooBar
  /// ```
  String toLowerCamelCase() {
    if (this.length < 2) return this.toLowerCase();
    return this[0].toLowerCase() + this.substring(1);
  }

  /// 转换为Kabab型式
  ///
  /// ```dart
  /// fooBar => foo-bar
  /// ```
  String toKababCase() {
    return this.replaceAllMapped(RegExp('(.+?)([A-Z])'),
        (match) => '${match.group(1)}-${match.group(2)}'.toLowerCase());
  }

  /// 转换为Snake型式
  ///
  /// ```dart
  /// fooBar => foo_bar
  /// ```
  String toSnakeCase() {
    return this
        .replaceAllMapped(RegExp('(.+?)([A-Z])'),
            (match) => '${match.group(1)}_${match.group(2)}')
        .toLowerCase();
  }

  /// 转换为大驼峰型式
  ///
  /// [pattern] 分隔符 ，默认为 "_"
  ///
  /// ```dart
  /// foo_bar => FooBar
  /// ```
  String toBigHump({Pattern pattern = '_'}) {
    return this.split(pattern).map((e) => e.toCapitalize()).join();
  }

  /// 转换为小驼峰型式
  ///
  /// [pattern] 分隔符 ，默认为 "_"
  ///
  /// ```dart
  /// foo_bar => fooBar
  /// ```
  String toLittleHump({Pattern pattern = '_'}) {
    return this
        .split(pattern)
        .map((e) => e.toCapitalize())
        .join()
        .toLowerCamelCase();
  }
}
